==> kyt-1.2.5.tgz: package/lib/actions/list.js <==
"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _react = _interopRequireDefault(require("react"));

var _ink = require("ink");

var _inkTable = _interopRequireDefault(require("ink-table"));

var _starterKyts = _interopRequireDefault(require("../config/starterKyts"));

var _jsxFileName = "/Users/202586/Sites/test.nytimes.com/kyt/packages/kyt-core/src/actions/list.js",
    _this = void 0;

var List = function List() {
  var data = Object.keys(_starterKyts["default"].supported).map(function (starterName) {
    var starter = _starterKyts["default"].supported[starterName];
    return {
      name: starter.displayName,
      description: starter.description,
      install: "select \"".concat(starter.slug, "\" during kyt setup")
    };
  });
  return /*#__PURE__*/_react["default"].createElement(_inkTable["default"], {
    data: data,
    header: function header(_ref) {
      var children = _ref.children;
      return /*#__PURE__*/_react["default"].createElement(_ink.Text, {
        color: "magenta",
        __self: _this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 16,
          columnNumber: 55
        }
      }, children);
    },
    __self: _this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 16,
      columnNumber: 10
    }
  });
};

List.displayName = "List";

module.exports = function () {
  (0, _ink.render)( /*#__PURE__*/_react["default"].createElement(List, {
    __self: _this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 20,
      columnNumber: 10
    }
  }));
};

==> kyt-1.2.7.tgz: package/lib/actions/list.js <==
"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
var _react = _interopRequireDefault(require("react"));
var _ink = require("ink");
var _inkTable = _interopRequireDefault(require("ink-table"));
var _starterKyts = _interopRequireDefault(require("../config/starterKyts"));
var _jsxFileName = "/Users/202586/Sites/test.nytimes.com/kyt-test/packages/kyt-core/src/actions/list.js",
  _this = void 0;
var List = function List() {
  var data = Object.keys(_starterKyts["default"].supported).map(function (starterName) {
    var starter = _starterKyts["default"].supported[starterName];
    return {
      name: starter.displayName,
      description: starter.description,
      install: "select \"".concat(starter.slug, "\" during kyt setup")
    };
  });
  return /*#__PURE__*/_react["default"].createElement(_inkTable["default"], {
    data: data,
    header: function header(_ref) {
      var children = _ref.children;
      return /*#__PURE__*/_react["default"].createElement(_ink.Text, {
        color: "magenta",
        __self: _this,
        __source: {
          fileName: _jsxFileName,
          lineNumber: 16,
          columnNumber: 55
        }
      }, children);
    },
    __self: _this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 16,
      columnNumber: 10
    }
  });
};
List.displayName = "List";
module.exports = function () {
  (0, _ink.render)( /*#__PURE__*/_react["default"].createElement(List, {
    __self: _this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 20,
      columnNumber: 10
    }
  }));
};
